from setuptools import setup

setup()

"""
Version History

0.2.1 - catch-up release for ISSST workshop

0.2.0 - catch-up release for ACLCA workshop

0.1.1post99 - 2024-05-15 get ready for PyPI release

0.1.1 - First split from lca-tools

"""
